FileCabinetWriter
=================

.. currentmodule:: wwt_data_formats.filecabinet

.. autoclass:: FileCabinetWriter
   :show-inheritance:

   .. rubric:: Methods Summary

   .. autosummary::

      ~FileCabinetWriter.add_file_with_data
      ~FileCabinetWriter.emit
      ~FileCabinetWriter.filenames

   .. rubric:: Methods Documentation

   .. automethod:: add_file_with_data
   .. automethod:: emit
   .. automethod:: filenames
